@@ -3,7 +3,7 @@
 # @Date:   2020-03-08 14:34:45
 # @E-mail: maoyongfan@163.com
 # @Last Modified by:   yongfanmao
-# @Last Modified time: 2020-03-30 19:12:45
+# @Last Modified time: 2020-08-19 19:15:00
 
 __version__ = "1.0"
 
@@ -14,7 +14,7 @@ import json
 
 class Request(object):
 
-	def request_client(self,url="http://10.111.31.252:8088/gct/soarequest", method='post', **kwargs):
+	def request_client(self,url="https://fox-backend.hellobike.cn/gct/soarequest", method='post', **kwargs):
 		"""
 			支持rpc请求与soap请求
 			支持加密http请求,请传参数 encode=True
@@ -67,7 +67,7 @@ class Request(object):
 			else:
 				# print ('haha',url,data)
 				if 'headers' in kwargs:
-					rep = session.request(url=url, method=method, json=kwargs['data'],headers=kwargs['headers'])
+					rep = session.request(url=url, method=method, json=kwargs.get('data',""),headers=kwargs['headers'])
 				else:
 					rep = session.request(url=url, method=method, json=kwargs.get('data',""))
 
@@ -115,15 +115,18 @@ if __name__ == '__main__':
 	# 	}}
 	# }
 
-	data = {
-		"env":"fat",
-		"addr":"10.111.71.35:55001",
-		"iface":"com.easybike.rideprocess.ifaces.AppCustomerServiceIface",
-		"method":"isForbiddenCity",
-		"request":{"arg0":
-			{"cityCode":""}}
-		}
-
+	# data = {
+	# 	"env":"fat",
+	# 	"addr":"10.111.71.35:55001",
+	# 	"iface":"com.easybike.rideprocess.ifaces.AppCustomerServiceIface",
+	# 	"method":"isForbiddenCity",
+	# 	"request":{"arg0":
+	# 		{"cityCode":""}}
+	# 	}
+	# data = {"addr":"10.111.14.20:61500",
+	# "iface":"com.hellobike.geo.ifaces.GeoServiceIface",
+	# "method":"nearBikes",
+	# "request":{"arg0":{"currentLat":31.123007541232639,"mode":2,"cityCode":"021","radiusNum":2000,"adCode":"310112","action":"user.ride.nearBikes","token":"e66dbadc66ef459a916264734b0ad85e","currentLng":121.36478569878473,"bikeTabType":1,"lat":31.123007541232639,"lng":121.36478569878473,"systemCode":"61","version":"5.40.0","needManhattan":True}}}
 
 	# data = {
 	# 	"env":"fat",
@@ -151,11 +154,15 @@ if __name__ == '__main__':
 	# "rideLicenseforce": 1,
 	# "signalType": 5
 	# }
+	data = {"addr":"10.71.2.42:9997",
+	"iface":"com.hellobike.geo.ifaces.GeoServiceIface",
+	"method":"nearBikesNumber",
+	"request":{"arg0": {"currentLat": 31.122925, "currentLng": 121.364965, "radiusNum": 15000, "cityCode": "021"}}}
 	headers = {'user-agent': 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/80.0.3987.132 Safari/537.36'}
 	request = Request()
 	#"http://10.111.30.72:8099/api/accountbalance"
 	url="https://fat-bike.hellobike.com/api"
-	# print(request.request_client(data=data))
+	print(request.request_client(data=data))
 
-	url="http://10.111.10.64:9298/setossbikeinfo1/?bikeNo=5710000013"
-	print (request.request_client(url=url,method='get'))
+	# url="http://10.111.10.64:9298/setossbikeinfo1/?bikeNo=5710000013"
+	# print (request.request_client(url=url,method='get'))
